from __future__ import annotations
from win32more._prelude import *
import win32more.Microsoft.Windows.AI
import win32more.Microsoft.Windows.AI.ContentSafety
import win32more.Microsoft.Windows.AI.Foundation
import win32more.Microsoft.Windows.AI.Text
import win32more.Windows.Foundation
import win32more.Windows.Foundation.Collections
class ConversationItem(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.Windows.AI.Text.IConversationItem
    _classid_ = 'Microsoft.Windows.AI.Text.ConversationItem'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.Windows.AI.Text.ConversationItem.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Microsoft.Windows.AI.Text.ConversationItem: ...
    @winrt_mixinmethod
    def get_Participant(self: win32more.Microsoft.Windows.AI.Text.IConversationItem) -> hstr: ...
    @winrt_mixinmethod
    def put_Participant(self: win32more.Microsoft.Windows.AI.Text.IConversationItem, value: hstr) -> Void: ...
    @winrt_mixinmethod
    def get_Message(self: win32more.Microsoft.Windows.AI.Text.IConversationItem) -> hstr: ...
    @winrt_mixinmethod
    def put_Message(self: win32more.Microsoft.Windows.AI.Text.IConversationItem, value: hstr) -> Void: ...
    Message = property(get_Message, put_Message)
    Participant = property(get_Participant, put_Participant)
class ConversationSummaryOptions(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.Windows.AI.Text.IConversationSummaryOptions
    _classid_ = 'Microsoft.Windows.AI.Text.ConversationSummaryOptions'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.Windows.AI.Text.ConversationSummaryOptions.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Microsoft.Windows.AI.Text.ConversationSummaryOptions: ...
    @winrt_mixinmethod
    def get_InputKind(self: win32more.Microsoft.Windows.AI.Text.IConversationSummaryOptions) -> win32more.Microsoft.Windows.AI.Text.InputKind: ...
    @winrt_mixinmethod
    def put_InputKind(self: win32more.Microsoft.Windows.AI.Text.IConversationSummaryOptions, value: win32more.Microsoft.Windows.AI.Text.InputKind) -> Void: ...
    @winrt_mixinmethod
    def get_IncludeMessageCitations(self: win32more.Microsoft.Windows.AI.Text.IConversationSummaryOptions) -> Boolean: ...
    @winrt_mixinmethod
    def put_IncludeMessageCitations(self: win32more.Microsoft.Windows.AI.Text.IConversationSummaryOptions, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_IncludeParticipantAttribution(self: win32more.Microsoft.Windows.AI.Text.IConversationSummaryOptions) -> Boolean: ...
    @winrt_mixinmethod
    def put_IncludeParticipantAttribution(self: win32more.Microsoft.Windows.AI.Text.IConversationSummaryOptions, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_MaxKeyPoints(self: win32more.Microsoft.Windows.AI.Text.IConversationSummaryOptions) -> UInt32: ...
    @winrt_mixinmethod
    def put_MaxKeyPoints(self: win32more.Microsoft.Windows.AI.Text.IConversationSummaryOptions, value: UInt32) -> Void: ...
    @winrt_mixinmethod
    def get_Language(self: win32more.Microsoft.Windows.AI.Text.IConversationSummaryOptions) -> hstr: ...
    @winrt_mixinmethod
    def put_Language(self: win32more.Microsoft.Windows.AI.Text.IConversationSummaryOptions, value: hstr) -> Void: ...
    IncludeMessageCitations = property(get_IncludeMessageCitations, put_IncludeMessageCitations)
    IncludeParticipantAttribution = property(get_IncludeParticipantAttribution, put_IncludeParticipantAttribution)
    InputKind = property(get_InputKind, put_InputKind)
    Language = property(get_Language, put_Language)
    MaxKeyPoints = property(get_MaxKeyPoints, put_MaxKeyPoints)
class IConversationItem(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.Windows.AI.Text.IConversationItem'
    _iid_ = Guid('{957b0b85-4d7e-5788-baae-af7cf256bb8e}')
    @winrt_commethod(6)
    def get_Participant(self) -> hstr: ...
    @winrt_commethod(7)
    def put_Participant(self, value: hstr) -> Void: ...
    @winrt_commethod(8)
    def get_Message(self) -> hstr: ...
    @winrt_commethod(9)
    def put_Message(self, value: hstr) -> Void: ...
    Message = property(get_Message, put_Message)
    Participant = property(get_Participant, put_Participant)
class IConversationSummaryOptions(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.Windows.AI.Text.IConversationSummaryOptions'
    _iid_ = Guid('{360bce9f-fd14-5d0e-bd24-fd78ed3038e6}')
    @winrt_commethod(6)
    def get_InputKind(self) -> win32more.Microsoft.Windows.AI.Text.InputKind: ...
    @winrt_commethod(7)
    def put_InputKind(self, value: win32more.Microsoft.Windows.AI.Text.InputKind) -> Void: ...
    @winrt_commethod(8)
    def get_IncludeMessageCitations(self) -> Boolean: ...
    @winrt_commethod(9)
    def put_IncludeMessageCitations(self, value: Boolean) -> Void: ...
    @winrt_commethod(10)
    def get_IncludeParticipantAttribution(self) -> Boolean: ...
    @winrt_commethod(11)
    def put_IncludeParticipantAttribution(self, value: Boolean) -> Void: ...
    @winrt_commethod(12)
    def get_MaxKeyPoints(self) -> UInt32: ...
    @winrt_commethod(13)
    def put_MaxKeyPoints(self, value: UInt32) -> Void: ...
    @winrt_commethod(14)
    def get_Language(self) -> hstr: ...
    @winrt_commethod(15)
    def put_Language(self, value: hstr) -> Void: ...
    IncludeMessageCitations = property(get_IncludeMessageCitations, put_IncludeMessageCitations)
    IncludeParticipantAttribution = property(get_IncludeParticipantAttribution, put_IncludeParticipantAttribution)
    InputKind = property(get_InputKind, put_InputKind)
    Language = property(get_Language, put_Language)
    MaxKeyPoints = property(get_MaxKeyPoints, put_MaxKeyPoints)
class ILanguageModel(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.Windows.AI.Text.ILanguageModel'
    _iid_ = Guid('{6331c629-8c86-5bfe-8c4e-9ca5573cc14b}')
class ILanguageModel2(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.Windows.AI.Text.ILanguageModel2'
    _iid_ = Guid('{653b714e-f9b3-51cb-954f-5ea58f63ab89}')
    @winrt_commethod(6)
    def GenerateResponseAsync(self, prompt: hstr) -> win32more.Windows.Foundation.IAsyncOperationWithProgress[win32more.Microsoft.Windows.AI.Text.LanguageModelResponseResult, hstr]: ...
    @winrt_commethod(7)
    def GenerateResponseAsync2(self, prompt: hstr, options: win32more.Microsoft.Windows.AI.Text.LanguageModelOptions) -> win32more.Windows.Foundation.IAsyncOperationWithProgress[win32more.Microsoft.Windows.AI.Text.LanguageModelResponseResult, hstr]: ...
    @winrt_commethod(8)
    def GenerateResponseAsync3(self, context: win32more.Microsoft.Windows.AI.Text.LanguageModelContext, prompt: hstr, options: win32more.Microsoft.Windows.AI.Text.LanguageModelOptions) -> win32more.Windows.Foundation.IAsyncOperationWithProgress[win32more.Microsoft.Windows.AI.Text.LanguageModelResponseResult, hstr]: ...
    @winrt_commethod(9)
    def GenerateResponseFromEmbeddingsAsync(self, promptEmbedding: win32more.Windows.Foundation.Collections.IIterable[win32more.Microsoft.Windows.AI.Foundation.EmbeddingVector]) -> win32more.Windows.Foundation.IAsyncOperationWithProgress[win32more.Microsoft.Windows.AI.Text.LanguageModelResponseResult, hstr]: ...
    @winrt_commethod(10)
    def GenerateResponseFromEmbeddingsAsync2(self, promptEmbedding: win32more.Windows.Foundation.Collections.IIterable[win32more.Microsoft.Windows.AI.Foundation.EmbeddingVector], options: win32more.Microsoft.Windows.AI.Text.LanguageModelOptions) -> win32more.Windows.Foundation.IAsyncOperationWithProgress[win32more.Microsoft.Windows.AI.Text.LanguageModelResponseResult, hstr]: ...
    @winrt_commethod(11)
    def GenerateResponseFromEmbeddingsAsync3(self, context: win32more.Microsoft.Windows.AI.Text.LanguageModelContext, promptEmbedding: win32more.Windows.Foundation.Collections.IIterable[win32more.Microsoft.Windows.AI.Foundation.EmbeddingVector], options: win32more.Microsoft.Windows.AI.Text.LanguageModelOptions) -> win32more.Windows.Foundation.IAsyncOperationWithProgress[win32more.Microsoft.Windows.AI.Text.LanguageModelResponseResult, hstr]: ...
    @winrt_commethod(12)
    def GenerateEmbeddingVectors(self, prompt: hstr) -> win32more.Microsoft.Windows.AI.Text.LanguageModelEmbeddingVectorResult: ...
    @winrt_commethod(13)
    def GenerateEmbeddingVectors2(self, prompt: hstr, contentFilterOptions: win32more.Microsoft.Windows.AI.ContentSafety.ContentFilterOptions) -> win32more.Microsoft.Windows.AI.Text.LanguageModelEmbeddingVectorResult: ...
    @winrt_commethod(14)
    def GetUsablePromptLength(self, prompt: hstr) -> UInt64: ...
    @winrt_commethod(15)
    def GetUsablePromptLength2(self, context: win32more.Microsoft.Windows.AI.Text.LanguageModelContext, prompt: hstr) -> UInt64: ...
    @winrt_commethod(16)
    def GetVectorSpaceId(self) -> Guid: ...
    @winrt_commethod(17)
    def CreateContext(self) -> win32more.Microsoft.Windows.AI.Text.LanguageModelContext: ...
    @winrt_commethod(18)
    def CreateContext2(self, systemPrompt: hstr) -> win32more.Microsoft.Windows.AI.Text.LanguageModelContext: ...
    @winrt_commethod(19)
    def CreateContext3(self, systemPrompt: hstr, contentFilterOptions: win32more.Microsoft.Windows.AI.ContentSafety.ContentFilterOptions) -> win32more.Microsoft.Windows.AI.Text.LanguageModelContext: ...
class ILanguageModelContext(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.Windows.AI.Text.ILanguageModelContext'
    _iid_ = Guid('{518b305c-7b69-5a33-8129-d47d6b8eec4e}')
class ILanguageModelEmbeddingVectorResult(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.Windows.AI.Text.ILanguageModelEmbeddingVectorResult'
    _iid_ = Guid('{4dbdb154-ee3c-56f6-a40b-413e95bd5acb}')
    @winrt_commethod(6)
    def get_EmbeddingVectors(self) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Microsoft.Windows.AI.Foundation.EmbeddingVector]: ...
    @winrt_commethod(7)
    def get_Status(self) -> win32more.Microsoft.Windows.AI.Text.LanguageModelResponseStatus: ...
    @winrt_commethod(8)
    def get_ExtendedError(self) -> win32more.Windows.Foundation.HResult: ...
    EmbeddingVectors = property(get_EmbeddingVectors, None)
    ExtendedError = property(get_ExtendedError, None)
    Status = property(get_Status, None)
class ILanguageModelOptions(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.Windows.AI.Text.ILanguageModelOptions'
    _iid_ = Guid('{7f380003-5a09-5f1f-afb0-aa483e3670cc}')
    @winrt_commethod(6)
    def get_Temperature(self) -> Single: ...
    @winrt_commethod(7)
    def put_Temperature(self, value: Single) -> Void: ...
    @winrt_commethod(8)
    def get_TopP(self) -> Single: ...
    @winrt_commethod(9)
    def put_TopP(self, value: Single) -> Void: ...
    @winrt_commethod(10)
    def get_TopK(self) -> UInt32: ...
    @winrt_commethod(11)
    def put_TopK(self, value: UInt32) -> Void: ...
    @winrt_commethod(12)
    def get_ContentFilterOptions(self) -> win32more.Microsoft.Windows.AI.ContentSafety.ContentFilterOptions: ...
    @winrt_commethod(13)
    def put_ContentFilterOptions(self, value: win32more.Microsoft.Windows.AI.ContentSafety.ContentFilterOptions) -> Void: ...
    ContentFilterOptions = property(get_ContentFilterOptions, put_ContentFilterOptions)
    Temperature = property(get_Temperature, put_Temperature)
    TopK = property(get_TopK, put_TopK)
    TopP = property(get_TopP, put_TopP)
class ILanguageModelResponseResult(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.Windows.AI.Text.ILanguageModelResponseResult'
    _iid_ = Guid('{3a256fff-a426-5d3b-8e4b-3ac84162471e}')
    @winrt_commethod(6)
    def get_Text(self) -> hstr: ...
    @winrt_commethod(7)
    def get_Status(self) -> win32more.Microsoft.Windows.AI.Text.LanguageModelResponseStatus: ...
    @winrt_commethod(8)
    def get_ExtendedError(self) -> win32more.Windows.Foundation.HResult: ...
    ExtendedError = property(get_ExtendedError, None)
    Status = property(get_Status, None)
    Text = property(get_Text, None)
class ILanguageModelStatics(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.Windows.AI.Text.ILanguageModelStatics'
    _iid_ = Guid('{8f18f9af-6095-553b-8d9d-6bcc98026546}')
    @winrt_commethod(6)
    def GetReadyState(self) -> win32more.Microsoft.Windows.AI.AIFeatureReadyState: ...
    @winrt_commethod(7)
    def EnsureReadyAsync(self) -> win32more.Windows.Foundation.IAsyncOperationWithProgress[win32more.Microsoft.Windows.AI.AIFeatureReadyResult, Double]: ...
    @winrt_commethod(8)
    def CreateAsync(self) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Microsoft.Windows.AI.Text.LanguageModel]: ...
class ITextRewriter(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.Windows.AI.Text.ITextRewriter'
    _iid_ = Guid('{eb1e7cf0-e110-506c-b0ea-7a288d8e7778}')
    @winrt_commethod(6)
    def RewriteAsync(self, text: hstr) -> win32more.Windows.Foundation.IAsyncOperationWithProgress[win32more.Microsoft.Windows.AI.Text.LanguageModelResponseResult, hstr]: ...
class ITextRewriter2(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.Windows.AI.Text.ITextRewriter2'
    _iid_ = Guid('{7937d261-13ce-5b24-b17c-fe5cd0be23b6}')
    @winrt_commethod(6)
    def RewriteAsync(self, text: hstr, tone: win32more.Microsoft.Windows.AI.Text.TextRewriteTone) -> win32more.Windows.Foundation.IAsyncOperationWithProgress[win32more.Microsoft.Windows.AI.Text.LanguageModelResponseResult, hstr]: ...
class ITextRewriterFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.Windows.AI.Text.ITextRewriterFactory'
    _iid_ = Guid('{f452e60d-ef50-5bc9-b483-217d5b4e7151}')
    @winrt_commethod(6)
    def CreateInstance(self, languageModel: win32more.Microsoft.Windows.AI.Text.LanguageModel) -> win32more.Microsoft.Windows.AI.Text.TextRewriter: ...
class ITextSummarizer(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.Windows.AI.Text.ITextSummarizer'
    _iid_ = Guid('{eef548c5-d7bc-50be-a8ab-29e241b78bd1}')
    @winrt_commethod(6)
    def SummarizeAsync(self, text: hstr) -> win32more.Windows.Foundation.IAsyncOperationWithProgress[win32more.Microsoft.Windows.AI.Text.LanguageModelResponseResult, hstr]: ...
    @winrt_commethod(7)
    def SummarizeParagraphAsync(self, text: hstr) -> win32more.Windows.Foundation.IAsyncOperationWithProgress[win32more.Microsoft.Windows.AI.Text.LanguageModelResponseResult, hstr]: ...
class ITextSummarizer2(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.Windows.AI.Text.ITextSummarizer2'
    _iid_ = Guid('{9e20797d-1ff6-5295-8cb6-d48fb8ba483b}')
    @winrt_commethod(6)
    def SummarizeConversationAsync(self, messages: win32more.Windows.Foundation.Collections.IVectorView[win32more.Microsoft.Windows.AI.Text.ConversationItem], options: win32more.Microsoft.Windows.AI.Text.ConversationSummaryOptions) -> win32more.Windows.Foundation.IAsyncOperationWithProgress[win32more.Microsoft.Windows.AI.Text.LanguageModelResponseResult, hstr]: ...
class ITextSummarizer3(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.Windows.AI.Text.ITextSummarizer3'
    _iid_ = Guid('{493d32b9-dbc9-5d4b-802f-90473850500e}')
    @winrt_commethod(6)
    def IsPromptLargerThanContext(self, messages: PassArray[win32more.Microsoft.Windows.AI.Text.ConversationItem], options: win32more.Microsoft.Windows.AI.Text.ConversationSummaryOptions, cutoffPosition: POINTER(UInt64)) -> Boolean: ...
class ITextSummarizer4(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.Windows.AI.Text.ITextSummarizer4'
    _iid_ = Guid('{5b7a28c0-7777-52e5-9934-b95b514cf535}')
    @winrt_commethod(6)
    def IsPromptLargerThanContext(self, text: hstr, cutoffPosition: POINTER(UInt64)) -> Boolean: ...
class ITextSummarizerFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.Windows.AI.Text.ITextSummarizerFactory'
    _iid_ = Guid('{b6a75913-4a1e-59e7-856a-ae7ab2383864}')
    @winrt_commethod(6)
    def CreateInstance(self, languageModel: win32more.Microsoft.Windows.AI.Text.LanguageModel) -> win32more.Microsoft.Windows.AI.Text.TextSummarizer: ...
class ITextToTableConverter(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.Windows.AI.Text.ITextToTableConverter'
    _iid_ = Guid('{a008d9ad-25ce-5a6b-9ceb-d8e95d04e10b}')
    @winrt_commethod(6)
    def ConvertAsync(self, text: hstr) -> win32more.Windows.Foundation.IAsyncOperationWithProgress[win32more.Microsoft.Windows.AI.Text.TextToTableResponseResult, hstr]: ...
class ITextToTableConverterFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.Windows.AI.Text.ITextToTableConverterFactory'
    _iid_ = Guid('{bb84cbb5-19c8-5857-b65d-705aa1486404}')
    @winrt_commethod(6)
    def CreateInstance(self, languageModel: win32more.Microsoft.Windows.AI.Text.LanguageModel) -> win32more.Microsoft.Windows.AI.Text.TextToTableConverter: ...
class ITextToTableResponseResult(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.Windows.AI.Text.ITextToTableResponseResult'
    _iid_ = Guid('{391fbf11-59cd-575d-834a-9ef823116f98}')
    @winrt_commethod(6)
    def GetRows(self) -> ReceiveArray[win32more.Microsoft.Windows.AI.Text.TextToTableRow]: ...
    @winrt_commethod(7)
    def get_Status(self) -> win32more.Microsoft.Windows.AI.Text.LanguageModelResponseStatus: ...
    @winrt_commethod(8)
    def get_ExtendedError(self) -> win32more.Windows.Foundation.HResult: ...
    ExtendedError = property(get_ExtendedError, None)
    Status = property(get_Status, None)
class ITextToTableRow(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.Windows.AI.Text.ITextToTableRow'
    _iid_ = Guid('{036294fe-e53c-5e66-93d2-7c92338db881}')
    @winrt_commethod(6)
    def GetColumns(self) -> ReceiveArray[hstr]: ...
class InputKind(Enum, Int32):
    GeneralConversation = 0
    Email = 1
class LanguageModel(ComPtr):
    extends: IInspectable
    implements: Tuple[ContextManagerProtocol]
    default_interface: win32more.Microsoft.Windows.AI.Text.ILanguageModel
    _classid_ = 'Microsoft.Windows.AI.Text.LanguageModel'
    @winrt_mixinmethod
    def GenerateResponseAsync(self: win32more.Microsoft.Windows.AI.Text.ILanguageModel2, prompt: hstr) -> win32more.Windows.Foundation.IAsyncOperationWithProgress[win32more.Microsoft.Windows.AI.Text.LanguageModelResponseResult, hstr]: ...
    @winrt_mixinmethod
    def GenerateResponseAsync2(self: win32more.Microsoft.Windows.AI.Text.ILanguageModel2, prompt: hstr, options: win32more.Microsoft.Windows.AI.Text.LanguageModelOptions) -> win32more.Windows.Foundation.IAsyncOperationWithProgress[win32more.Microsoft.Windows.AI.Text.LanguageModelResponseResult, hstr]: ...
    @winrt_mixinmethod
    def GenerateResponseAsync3(self: win32more.Microsoft.Windows.AI.Text.ILanguageModel2, context: win32more.Microsoft.Windows.AI.Text.LanguageModelContext, prompt: hstr, options: win32more.Microsoft.Windows.AI.Text.LanguageModelOptions) -> win32more.Windows.Foundation.IAsyncOperationWithProgress[win32more.Microsoft.Windows.AI.Text.LanguageModelResponseResult, hstr]: ...
    @winrt_mixinmethod
    def GenerateResponseFromEmbeddingsAsync(self: win32more.Microsoft.Windows.AI.Text.ILanguageModel2, promptEmbedding: win32more.Windows.Foundation.Collections.IIterable[win32more.Microsoft.Windows.AI.Foundation.EmbeddingVector]) -> win32more.Windows.Foundation.IAsyncOperationWithProgress[win32more.Microsoft.Windows.AI.Text.LanguageModelResponseResult, hstr]: ...
    @winrt_mixinmethod
    def GenerateResponseFromEmbeddingsAsync2(self: win32more.Microsoft.Windows.AI.Text.ILanguageModel2, promptEmbedding: win32more.Windows.Foundation.Collections.IIterable[win32more.Microsoft.Windows.AI.Foundation.EmbeddingVector], options: win32more.Microsoft.Windows.AI.Text.LanguageModelOptions) -> win32more.Windows.Foundation.IAsyncOperationWithProgress[win32more.Microsoft.Windows.AI.Text.LanguageModelResponseResult, hstr]: ...
    @winrt_mixinmethod
    def GenerateResponseFromEmbeddingsAsync3(self: win32more.Microsoft.Windows.AI.Text.ILanguageModel2, context: win32more.Microsoft.Windows.AI.Text.LanguageModelContext, promptEmbedding: win32more.Windows.Foundation.Collections.IIterable[win32more.Microsoft.Windows.AI.Foundation.EmbeddingVector], options: win32more.Microsoft.Windows.AI.Text.LanguageModelOptions) -> win32more.Windows.Foundation.IAsyncOperationWithProgress[win32more.Microsoft.Windows.AI.Text.LanguageModelResponseResult, hstr]: ...
    @winrt_mixinmethod
    def GenerateEmbeddingVectors(self: win32more.Microsoft.Windows.AI.Text.ILanguageModel2, prompt: hstr) -> win32more.Microsoft.Windows.AI.Text.LanguageModelEmbeddingVectorResult: ...
    @winrt_mixinmethod
    def GenerateEmbeddingVectors2(self: win32more.Microsoft.Windows.AI.Text.ILanguageModel2, prompt: hstr, contentFilterOptions: win32more.Microsoft.Windows.AI.ContentSafety.ContentFilterOptions) -> win32more.Microsoft.Windows.AI.Text.LanguageModelEmbeddingVectorResult: ...
    @winrt_mixinmethod
    def GetUsablePromptLength(self: win32more.Microsoft.Windows.AI.Text.ILanguageModel2, prompt: hstr) -> UInt64: ...
    @winrt_mixinmethod
    def GetUsablePromptLength2(self: win32more.Microsoft.Windows.AI.Text.ILanguageModel2, context: win32more.Microsoft.Windows.AI.Text.LanguageModelContext, prompt: hstr) -> UInt64: ...
    @winrt_mixinmethod
    def GetVectorSpaceId(self: win32more.Microsoft.Windows.AI.Text.ILanguageModel2) -> Guid: ...
    @winrt_mixinmethod
    def CreateContext(self: win32more.Microsoft.Windows.AI.Text.ILanguageModel2) -> win32more.Microsoft.Windows.AI.Text.LanguageModelContext: ...
    @winrt_mixinmethod
    def CreateContext2(self: win32more.Microsoft.Windows.AI.Text.ILanguageModel2, systemPrompt: hstr) -> win32more.Microsoft.Windows.AI.Text.LanguageModelContext: ...
    @winrt_mixinmethod
    def CreateContext3(self: win32more.Microsoft.Windows.AI.Text.ILanguageModel2, systemPrompt: hstr, contentFilterOptions: win32more.Microsoft.Windows.AI.ContentSafety.ContentFilterOptions) -> win32more.Microsoft.Windows.AI.Text.LanguageModelContext: ...
    @winrt_mixinmethod
    def Close(self: win32more.Windows.Foundation.IClosable) -> Void: ...
    @winrt_classmethod
    def GetReadyState(cls: win32more.Microsoft.Windows.AI.Text.ILanguageModelStatics) -> win32more.Microsoft.Windows.AI.AIFeatureReadyState: ...
    @winrt_classmethod
    def EnsureReadyAsync(cls: win32more.Microsoft.Windows.AI.Text.ILanguageModelStatics) -> win32more.Windows.Foundation.IAsyncOperationWithProgress[win32more.Microsoft.Windows.AI.AIFeatureReadyResult, Double]: ...
    @winrt_classmethod
    def CreateAsync(cls: win32more.Microsoft.Windows.AI.Text.ILanguageModelStatics) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Microsoft.Windows.AI.Text.LanguageModel]: ...
class LanguageModelContext(ComPtr):
    extends: IInspectable
    implements: Tuple[ContextManagerProtocol]
    default_interface: win32more.Microsoft.Windows.AI.Text.ILanguageModelContext
    _classid_ = 'Microsoft.Windows.AI.Text.LanguageModelContext'
    @winrt_mixinmethod
    def Close(self: win32more.Windows.Foundation.IClosable) -> Void: ...
LanguageModelContract: UInt32 = 131072
class LanguageModelEmbeddingVectorResult(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.Windows.AI.Text.ILanguageModelEmbeddingVectorResult
    _classid_ = 'Microsoft.Windows.AI.Text.LanguageModelEmbeddingVectorResult'
    @winrt_mixinmethod
    def get_EmbeddingVectors(self: win32more.Microsoft.Windows.AI.Text.ILanguageModelEmbeddingVectorResult) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Microsoft.Windows.AI.Foundation.EmbeddingVector]: ...
    @winrt_mixinmethod
    def get_Status(self: win32more.Microsoft.Windows.AI.Text.ILanguageModelEmbeddingVectorResult) -> win32more.Microsoft.Windows.AI.Text.LanguageModelResponseStatus: ...
    @winrt_mixinmethod
    def get_ExtendedError(self: win32more.Microsoft.Windows.AI.Text.ILanguageModelEmbeddingVectorResult) -> win32more.Windows.Foundation.HResult: ...
    EmbeddingVectors = property(get_EmbeddingVectors, None)
    ExtendedError = property(get_ExtendedError, None)
    Status = property(get_Status, None)
class LanguageModelOptions(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.Windows.AI.Text.ILanguageModelOptions
    _classid_ = 'Microsoft.Windows.AI.Text.LanguageModelOptions'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.Windows.AI.Text.LanguageModelOptions.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Microsoft.Windows.AI.Text.LanguageModelOptions: ...
    @winrt_mixinmethod
    def get_Temperature(self: win32more.Microsoft.Windows.AI.Text.ILanguageModelOptions) -> Single: ...
    @winrt_mixinmethod
    def put_Temperature(self: win32more.Microsoft.Windows.AI.Text.ILanguageModelOptions, value: Single) -> Void: ...
    @winrt_mixinmethod
    def get_TopP(self: win32more.Microsoft.Windows.AI.Text.ILanguageModelOptions) -> Single: ...
    @winrt_mixinmethod
    def put_TopP(self: win32more.Microsoft.Windows.AI.Text.ILanguageModelOptions, value: Single) -> Void: ...
    @winrt_mixinmethod
    def get_TopK(self: win32more.Microsoft.Windows.AI.Text.ILanguageModelOptions) -> UInt32: ...
    @winrt_mixinmethod
    def put_TopK(self: win32more.Microsoft.Windows.AI.Text.ILanguageModelOptions, value: UInt32) -> Void: ...
    @winrt_mixinmethod
    def get_ContentFilterOptions(self: win32more.Microsoft.Windows.AI.Text.ILanguageModelOptions) -> win32more.Microsoft.Windows.AI.ContentSafety.ContentFilterOptions: ...
    @winrt_mixinmethod
    def put_ContentFilterOptions(self: win32more.Microsoft.Windows.AI.Text.ILanguageModelOptions, value: win32more.Microsoft.Windows.AI.ContentSafety.ContentFilterOptions) -> Void: ...
    ContentFilterOptions = property(get_ContentFilterOptions, put_ContentFilterOptions)
    Temperature = property(get_Temperature, put_Temperature)
    TopK = property(get_TopK, put_TopK)
    TopP = property(get_TopP, put_TopP)
class LanguageModelResponseResult(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.Windows.AI.Text.ILanguageModelResponseResult
    _classid_ = 'Microsoft.Windows.AI.Text.LanguageModelResponseResult'
    @winrt_mixinmethod
    def get_Text(self: win32more.Microsoft.Windows.AI.Text.ILanguageModelResponseResult) -> hstr: ...
    @winrt_mixinmethod
    def get_Status(self: win32more.Microsoft.Windows.AI.Text.ILanguageModelResponseResult) -> win32more.Microsoft.Windows.AI.Text.LanguageModelResponseStatus: ...
    @winrt_mixinmethod
    def get_ExtendedError(self: win32more.Microsoft.Windows.AI.Text.ILanguageModelResponseResult) -> win32more.Windows.Foundation.HResult: ...
    ExtendedError = property(get_ExtendedError, None)
    Status = property(get_Status, None)
    Text = property(get_Text, None)
class LanguageModelResponseStatus(Enum, Int32):
    Complete = 0
    InProgress = 1
    BlockedByPolicy = 2
    PromptLargerThanContext = 3
    PromptBlockedByContentModeration = 4
    ResponseBlockedByContentModeration = 5
    Error = 6
TextIntelligenceContract: UInt32 = 393216
class TextRewriteTone(Enum, Int32):
    Default = 0
    General = 1
    Casual = 2
    Concise = 3
    Formal = 4
class TextRewriter(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.Windows.AI.Text.ITextRewriter
    _classid_ = 'Microsoft.Windows.AI.Text.TextRewriter'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 1:
            super().__init__(move=win32more.Microsoft.Windows.AI.Text.TextRewriter.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Microsoft.Windows.AI.Text.ITextRewriterFactory, languageModel: win32more.Microsoft.Windows.AI.Text.LanguageModel) -> win32more.Microsoft.Windows.AI.Text.TextRewriter: ...
    @winrt_overload
    @winrt_mixinmethod
    def RewriteAsync(self: win32more.Microsoft.Windows.AI.Text.ITextRewriter, text: hstr) -> win32more.Windows.Foundation.IAsyncOperationWithProgress[win32more.Microsoft.Windows.AI.Text.LanguageModelResponseResult, hstr]: ...
    @RewriteAsync.register
    @winrt_mixinmethod
    def RewriteAsync(self: win32more.Microsoft.Windows.AI.Text.ITextRewriter2, text: hstr, tone: win32more.Microsoft.Windows.AI.Text.TextRewriteTone) -> win32more.Windows.Foundation.IAsyncOperationWithProgress[win32more.Microsoft.Windows.AI.Text.LanguageModelResponseResult, hstr]: ...
class TextSummarizer(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.Windows.AI.Text.ITextSummarizer
    _classid_ = 'Microsoft.Windows.AI.Text.TextSummarizer'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 1:
            super().__init__(move=win32more.Microsoft.Windows.AI.Text.TextSummarizer.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Microsoft.Windows.AI.Text.ITextSummarizerFactory, languageModel: win32more.Microsoft.Windows.AI.Text.LanguageModel) -> win32more.Microsoft.Windows.AI.Text.TextSummarizer: ...
    @winrt_mixinmethod
    def SummarizeAsync(self: win32more.Microsoft.Windows.AI.Text.ITextSummarizer, text: hstr) -> win32more.Windows.Foundation.IAsyncOperationWithProgress[win32more.Microsoft.Windows.AI.Text.LanguageModelResponseResult, hstr]: ...
    @winrt_mixinmethod
    def SummarizeParagraphAsync(self: win32more.Microsoft.Windows.AI.Text.ITextSummarizer, text: hstr) -> win32more.Windows.Foundation.IAsyncOperationWithProgress[win32more.Microsoft.Windows.AI.Text.LanguageModelResponseResult, hstr]: ...
    @winrt_mixinmethod
    def SummarizeConversationAsync(self: win32more.Microsoft.Windows.AI.Text.ITextSummarizer2, messages: win32more.Windows.Foundation.Collections.IVectorView[win32more.Microsoft.Windows.AI.Text.ConversationItem], options: win32more.Microsoft.Windows.AI.Text.ConversationSummaryOptions) -> win32more.Windows.Foundation.IAsyncOperationWithProgress[win32more.Microsoft.Windows.AI.Text.LanguageModelResponseResult, hstr]: ...
    @winrt_overload
    @winrt_mixinmethod
    def IsPromptLargerThanContext(self: win32more.Microsoft.Windows.AI.Text.ITextSummarizer3, messages: PassArray[win32more.Microsoft.Windows.AI.Text.ConversationItem], options: win32more.Microsoft.Windows.AI.Text.ConversationSummaryOptions, cutoffPosition: POINTER(UInt64)) -> Boolean: ...
    @IsPromptLargerThanContext.register
    @winrt_mixinmethod
    def IsPromptLargerThanContext(self: win32more.Microsoft.Windows.AI.Text.ITextSummarizer4, text: hstr, cutoffPosition: POINTER(UInt64)) -> Boolean: ...
class TextToTableConverter(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.Windows.AI.Text.ITextToTableConverter
    _classid_ = 'Microsoft.Windows.AI.Text.TextToTableConverter'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 1:
            super().__init__(move=win32more.Microsoft.Windows.AI.Text.TextToTableConverter.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Microsoft.Windows.AI.Text.ITextToTableConverterFactory, languageModel: win32more.Microsoft.Windows.AI.Text.LanguageModel) -> win32more.Microsoft.Windows.AI.Text.TextToTableConverter: ...
    @winrt_mixinmethod
    def ConvertAsync(self: win32more.Microsoft.Windows.AI.Text.ITextToTableConverter, text: hstr) -> win32more.Windows.Foundation.IAsyncOperationWithProgress[win32more.Microsoft.Windows.AI.Text.TextToTableResponseResult, hstr]: ...
class TextToTableResponseResult(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.Windows.AI.Text.ITextToTableResponseResult
    _classid_ = 'Microsoft.Windows.AI.Text.TextToTableResponseResult'
    @winrt_mixinmethod
    def GetRows(self: win32more.Microsoft.Windows.AI.Text.ITextToTableResponseResult) -> ReceiveArray[win32more.Microsoft.Windows.AI.Text.TextToTableRow]: ...
    @winrt_mixinmethod
    def get_Status(self: win32more.Microsoft.Windows.AI.Text.ITextToTableResponseResult) -> win32more.Microsoft.Windows.AI.Text.LanguageModelResponseStatus: ...
    @winrt_mixinmethod
    def get_ExtendedError(self: win32more.Microsoft.Windows.AI.Text.ITextToTableResponseResult) -> win32more.Windows.Foundation.HResult: ...
    ExtendedError = property(get_ExtendedError, None)
    Status = property(get_Status, None)
class TextToTableRow(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.Windows.AI.Text.ITextToTableRow
    _classid_ = 'Microsoft.Windows.AI.Text.TextToTableRow'
    @winrt_mixinmethod
    def GetColumns(self: win32more.Microsoft.Windows.AI.Text.ITextToTableRow) -> ReceiveArray[hstr]: ...


make_ready(__name__)



from __future__ import annotations
from win32more._prelude import *
import win32more.Microsoft.Windows.Foundation
DecimalContract: UInt32 = 65536
class DecimalHelper(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.Windows.Foundation.DecimalHelper'
    @winrt_classmethod
    def FromBoolean(cls: win32more.Microsoft.Windows.Foundation.IDecimalHelperStatics, value: Boolean) -> win32more.Microsoft.Windows.Foundation.DecimalValue: ...
    @winrt_classmethod
    def FromInt16(cls: win32more.Microsoft.Windows.Foundation.IDecimalHelperStatics, value: Int16) -> win32more.Microsoft.Windows.Foundation.DecimalValue: ...
    @winrt_classmethod
    def FromInt32(cls: win32more.Microsoft.Windows.Foundation.IDecimalHelperStatics, value: Int32) -> win32more.Microsoft.Windows.Foundation.DecimalValue: ...
    @winrt_classmethod
    def FromInt64(cls: win32more.Microsoft.Windows.Foundation.IDecimalHelperStatics, value: Int64) -> win32more.Microsoft.Windows.Foundation.DecimalValue: ...
    @winrt_classmethod
    def FromUInt8(cls: win32more.Microsoft.Windows.Foundation.IDecimalHelperStatics, value: Byte) -> win32more.Microsoft.Windows.Foundation.DecimalValue: ...
    @winrt_classmethod
    def FromUInt16(cls: win32more.Microsoft.Windows.Foundation.IDecimalHelperStatics, value: UInt16) -> win32more.Microsoft.Windows.Foundation.DecimalValue: ...
    @winrt_classmethod
    def FromUInt32(cls: win32more.Microsoft.Windows.Foundation.IDecimalHelperStatics, value: UInt32) -> win32more.Microsoft.Windows.Foundation.DecimalValue: ...
    @winrt_classmethod
    def FromUInt64(cls: win32more.Microsoft.Windows.Foundation.IDecimalHelperStatics, value: UInt64) -> win32more.Microsoft.Windows.Foundation.DecimalValue: ...
    @winrt_classmethod
    def FromSingle(cls: win32more.Microsoft.Windows.Foundation.IDecimalHelperStatics, value: Single) -> win32more.Microsoft.Windows.Foundation.DecimalValue: ...
    @winrt_classmethod
    def FromDouble(cls: win32more.Microsoft.Windows.Foundation.IDecimalHelperStatics, value: Double) -> win32more.Microsoft.Windows.Foundation.DecimalValue: ...
    @winrt_classmethod
    def FromString(cls: win32more.Microsoft.Windows.Foundation.IDecimalHelperStatics, source: hstr) -> win32more.Microsoft.Windows.Foundation.DecimalValue: ...
    @winrt_classmethod
    def FromStringInvariant(cls: win32more.Microsoft.Windows.Foundation.IDecimalHelperStatics, source: hstr) -> win32more.Microsoft.Windows.Foundation.DecimalValue: ...
    @winrt_classmethod
    def FromStringWithLocale(cls: win32more.Microsoft.Windows.Foundation.IDecimalHelperStatics, source: hstr, localeName: hstr) -> win32more.Microsoft.Windows.Foundation.DecimalValue: ...
    @winrt_classmethod
    def TryFromString(cls: win32more.Microsoft.Windows.Foundation.IDecimalHelperStatics, source: hstr, value: POINTER(win32more.Microsoft.Windows.Foundation.DecimalValue)) -> Boolean: ...
    @winrt_classmethod
    def TryFromStringInvariant(cls: win32more.Microsoft.Windows.Foundation.IDecimalHelperStatics, source: hstr, value: POINTER(win32more.Microsoft.Windows.Foundation.DecimalValue)) -> Boolean: ...
    @winrt_classmethod
    def TryFromStringWithLocale(cls: win32more.Microsoft.Windows.Foundation.IDecimalHelperStatics, source: hstr, localeName: hstr, value: POINTER(win32more.Microsoft.Windows.Foundation.DecimalValue)) -> Boolean: ...
    @winrt_classmethod
    def ToBoolean(cls: win32more.Microsoft.Windows.Foundation.IDecimalHelperStatics, value: win32more.Microsoft.Windows.Foundation.DecimalValue) -> Boolean: ...
    @winrt_classmethod
    def ToInt16(cls: win32more.Microsoft.Windows.Foundation.IDecimalHelperStatics, value: win32more.Microsoft.Windows.Foundation.DecimalValue) -> Int16: ...
    @winrt_classmethod
    def ToInt32(cls: win32more.Microsoft.Windows.Foundation.IDecimalHelperStatics, value: win32more.Microsoft.Windows.Foundation.DecimalValue) -> Int32: ...
    @winrt_classmethod
    def ToInt64(cls: win32more.Microsoft.Windows.Foundation.IDecimalHelperStatics, value: win32more.Microsoft.Windows.Foundation.DecimalValue) -> Int64: ...
    @winrt_classmethod
    def ToUInt8(cls: win32more.Microsoft.Windows.Foundation.IDecimalHelperStatics, value: win32more.Microsoft.Windows.Foundation.DecimalValue) -> Byte: ...
    @winrt_classmethod
    def ToUInt16(cls: win32more.Microsoft.Windows.Foundation.IDecimalHelperStatics, value: win32more.Microsoft.Windows.Foundation.DecimalValue) -> UInt16: ...
    @winrt_classmethod
    def ToUInt32(cls: win32more.Microsoft.Windows.Foundation.IDecimalHelperStatics, value: win32more.Microsoft.Windows.Foundation.DecimalValue) -> UInt32: ...
    @winrt_classmethod
    def ToUInt64(cls: win32more.Microsoft.Windows.Foundation.IDecimalHelperStatics, value: win32more.Microsoft.Windows.Foundation.DecimalValue) -> UInt64: ...
    @winrt_classmethod
    def ToSingle(cls: win32more.Microsoft.Windows.Foundation.IDecimalHelperStatics, value: win32more.Microsoft.Windows.Foundation.DecimalValue) -> Single: ...
    @winrt_classmethod
    def ToDouble(cls: win32more.Microsoft.Windows.Foundation.IDecimalHelperStatics, value: win32more.Microsoft.Windows.Foundation.DecimalValue) -> Double: ...
    @winrt_classmethod
    def ToString(cls: win32more.Microsoft.Windows.Foundation.IDecimalHelperStatics, value: win32more.Microsoft.Windows.Foundation.DecimalValue) -> hstr: ...
    @winrt_classmethod
    def ToStringInvariant(cls: win32more.Microsoft.Windows.Foundation.IDecimalHelperStatics, value: win32more.Microsoft.Windows.Foundation.DecimalValue) -> hstr: ...
    @winrt_classmethod
    def ToStringWithLocale(cls: win32more.Microsoft.Windows.Foundation.IDecimalHelperStatics, value: win32more.Microsoft.Windows.Foundation.DecimalValue, localeName: hstr) -> hstr: ...
    @winrt_classmethod
    def Equals(cls: win32more.Microsoft.Windows.Foundation.IDecimalHelperStatics, left: win32more.Microsoft.Windows.Foundation.DecimalValue, right: win32more.Microsoft.Windows.Foundation.DecimalValue) -> Boolean: ...
    @winrt_classmethod
    def Compare(cls: win32more.Microsoft.Windows.Foundation.IDecimalHelperStatics, left: win32more.Microsoft.Windows.Foundation.DecimalValue, right: win32more.Microsoft.Windows.Foundation.DecimalValue) -> Int32: ...
    @winrt_classmethod
    def IsValid(cls: win32more.Microsoft.Windows.Foundation.IDecimalHelperStatics, value: win32more.Microsoft.Windows.Foundation.DecimalValue) -> Boolean: ...
    @winrt_classmethod
    def IsInteger(cls: win32more.Microsoft.Windows.Foundation.IDecimalHelperStatics, value: win32more.Microsoft.Windows.Foundation.DecimalValue) -> Boolean: ...
    @winrt_classmethod
    def Scale(cls: win32more.Microsoft.Windows.Foundation.IDecimalHelperStatics, value: win32more.Microsoft.Windows.Foundation.DecimalValue) -> Byte: ...
    @winrt_classmethod
    def Sign(cls: win32more.Microsoft.Windows.Foundation.IDecimalHelperStatics, value: win32more.Microsoft.Windows.Foundation.DecimalValue) -> Int32: ...
    @winrt_classmethod
    def MaxScale(cls: win32more.Microsoft.Windows.Foundation.IDecimalHelperStatics) -> Byte: ...
    @winrt_classmethod
    def MaxValue(cls: win32more.Microsoft.Windows.Foundation.IDecimalHelperStatics) -> win32more.Microsoft.Windows.Foundation.DecimalValue: ...
    @winrt_classmethod
    def MinValue(cls: win32more.Microsoft.Windows.Foundation.IDecimalHelperStatics) -> win32more.Microsoft.Windows.Foundation.DecimalValue: ...
    @winrt_classmethod
    def Negate(cls: win32more.Microsoft.Windows.Foundation.IDecimalHelperStatics, value: win32more.Microsoft.Windows.Foundation.DecimalValue) -> win32more.Microsoft.Windows.Foundation.DecimalValue: ...
    @winrt_classmethod
    def Abs(cls: win32more.Microsoft.Windows.Foundation.IDecimalHelperStatics, value: win32more.Microsoft.Windows.Foundation.DecimalValue) -> win32more.Microsoft.Windows.Foundation.DecimalValue: ...
    @winrt_classmethod
    def Truncate(cls: win32more.Microsoft.Windows.Foundation.IDecimalHelperStatics, value: win32more.Microsoft.Windows.Foundation.DecimalValue) -> win32more.Microsoft.Windows.Foundation.DecimalValue: ...
    @winrt_classmethod
    def Floor(cls: win32more.Microsoft.Windows.Foundation.IDecimalHelperStatics, value: win32more.Microsoft.Windows.Foundation.DecimalValue) -> win32more.Microsoft.Windows.Foundation.DecimalValue: ...
    @winrt_classmethod
    def Ceiling(cls: win32more.Microsoft.Windows.Foundation.IDecimalHelperStatics, value: win32more.Microsoft.Windows.Foundation.DecimalValue) -> win32more.Microsoft.Windows.Foundation.DecimalValue: ...
    @winrt_classmethod
    def Round(cls: win32more.Microsoft.Windows.Foundation.IDecimalHelperStatics, value: win32more.Microsoft.Windows.Foundation.DecimalValue, decimalPlaces: Int32) -> win32more.Microsoft.Windows.Foundation.DecimalValue: ...
    @winrt_classmethod
    def Clamp(cls: win32more.Microsoft.Windows.Foundation.IDecimalHelperStatics, value: win32more.Microsoft.Windows.Foundation.DecimalValue, min: win32more.Microsoft.Windows.Foundation.DecimalValue, max: win32more.Microsoft.Windows.Foundation.DecimalValue) -> win32more.Microsoft.Windows.Foundation.DecimalValue: ...
    @winrt_classmethod
    def Add(cls: win32more.Microsoft.Windows.Foundation.IDecimalHelperStatics, left: win32more.Microsoft.Windows.Foundation.DecimalValue, right: win32more.Microsoft.Windows.Foundation.DecimalValue) -> win32more.Microsoft.Windows.Foundation.DecimalValue: ...
    @winrt_classmethod
    def Subtract(cls: win32more.Microsoft.Windows.Foundation.IDecimalHelperStatics, left: win32more.Microsoft.Windows.Foundation.DecimalValue, right: win32more.Microsoft.Windows.Foundation.DecimalValue) -> win32more.Microsoft.Windows.Foundation.DecimalValue: ...
    @winrt_classmethod
    def Multiply(cls: win32more.Microsoft.Windows.Foundation.IDecimalHelperStatics, left: win32more.Microsoft.Windows.Foundation.DecimalValue, right: win32more.Microsoft.Windows.Foundation.DecimalValue) -> win32more.Microsoft.Windows.Foundation.DecimalValue: ...
    @winrt_classmethod
    def Divide(cls: win32more.Microsoft.Windows.Foundation.IDecimalHelperStatics, left: win32more.Microsoft.Windows.Foundation.DecimalValue, right: win32more.Microsoft.Windows.Foundation.DecimalValue) -> win32more.Microsoft.Windows.Foundation.DecimalValue: ...
    @winrt_classmethod
    def Modulo(cls: win32more.Microsoft.Windows.Foundation.IDecimalHelperStatics, left: win32more.Microsoft.Windows.Foundation.DecimalValue, right: win32more.Microsoft.Windows.Foundation.DecimalValue) -> win32more.Microsoft.Windows.Foundation.DecimalValue: ...
class DecimalValue(Structure):
    _name_ = 'Microsoft.Windows.Foundation.DecimalValue'
    Reserved: UInt16
    Scale: Byte
    Sign: Byte
    Hi32: UInt32
    Lo64: UInt64
class IDecimalHelperStatics(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.Windows.Foundation.IDecimalHelperStatics'
    _iid_ = Guid('{ba09a415-e26c-55b3-9b76-b3affd556a7f}')
    @winrt_commethod(6)
    def FromBoolean(self, value: Boolean) -> win32more.Microsoft.Windows.Foundation.DecimalValue: ...
    @winrt_commethod(7)
    def FromInt16(self, value: Int16) -> win32more.Microsoft.Windows.Foundation.DecimalValue: ...
    @winrt_commethod(8)
    def FromInt32(self, value: Int32) -> win32more.Microsoft.Windows.Foundation.DecimalValue: ...
    @winrt_commethod(9)
    def FromInt64(self, value: Int64) -> win32more.Microsoft.Windows.Foundation.DecimalValue: ...
    @winrt_commethod(10)
    def FromUInt8(self, value: Byte) -> win32more.Microsoft.Windows.Foundation.DecimalValue: ...
    @winrt_commethod(11)
    def FromUInt16(self, value: UInt16) -> win32more.Microsoft.Windows.Foundation.DecimalValue: ...
    @winrt_commethod(12)
    def FromUInt32(self, value: UInt32) -> win32more.Microsoft.Windows.Foundation.DecimalValue: ...
    @winrt_commethod(13)
    def FromUInt64(self, value: UInt64) -> win32more.Microsoft.Windows.Foundation.DecimalValue: ...
    @winrt_commethod(14)
    def FromSingle(self, value: Single) -> win32more.Microsoft.Windows.Foundation.DecimalValue: ...
    @winrt_commethod(15)
    def FromDouble(self, value: Double) -> win32more.Microsoft.Windows.Foundation.DecimalValue: ...
    @winrt_commethod(16)
    def FromString(self, source: hstr) -> win32more.Microsoft.Windows.Foundation.DecimalValue: ...
    @winrt_commethod(17)
    def FromStringInvariant(self, source: hstr) -> win32more.Microsoft.Windows.Foundation.DecimalValue: ...
    @winrt_commethod(18)
    def FromStringWithLocale(self, source: hstr, localeName: hstr) -> win32more.Microsoft.Windows.Foundation.DecimalValue: ...
    @winrt_commethod(19)
    def TryFromString(self, source: hstr, value: POINTER(win32more.Microsoft.Windows.Foundation.DecimalValue)) -> Boolean: ...
    @winrt_commethod(20)
    def TryFromStringInvariant(self, source: hstr, value: POINTER(win32more.Microsoft.Windows.Foundation.DecimalValue)) -> Boolean: ...
    @winrt_commethod(21)
    def TryFromStringWithLocale(self, source: hstr, localeName: hstr, value: POINTER(win32more.Microsoft.Windows.Foundation.DecimalValue)) -> Boolean: ...
    @winrt_commethod(22)
    def ToBoolean(self, value: win32more.Microsoft.Windows.Foundation.DecimalValue) -> Boolean: ...
    @winrt_commethod(23)
    def ToInt16(self, value: win32more.Microsoft.Windows.Foundation.DecimalValue) -> Int16: ...
    @winrt_commethod(24)
    def ToInt32(self, value: win32more.Microsoft.Windows.Foundation.DecimalValue) -> Int32: ...
    @winrt_commethod(25)
    def ToInt64(self, value: win32more.Microsoft.Windows.Foundation.DecimalValue) -> Int64: ...
    @winrt_commethod(26)
    def ToUInt8(self, value: win32more.Microsoft.Windows.Foundation.DecimalValue) -> Byte: ...
    @winrt_commethod(27)
    def ToUInt16(self, value: win32more.Microsoft.Windows.Foundation.DecimalValue) -> UInt16: ...
    @winrt_commethod(28)
    def ToUInt32(self, value: win32more.Microsoft.Windows.Foundation.DecimalValue) -> UInt32: ...
    @winrt_commethod(29)
    def ToUInt64(self, value: win32more.Microsoft.Windows.Foundation.DecimalValue) -> UInt64: ...
    @winrt_commethod(30)
    def ToSingle(self, value: win32more.Microsoft.Windows.Foundation.DecimalValue) -> Single: ...
    @winrt_commethod(31)
    def ToDouble(self, value: win32more.Microsoft.Windows.Foundation.DecimalValue) -> Double: ...
    @winrt_commethod(32)
    def ToString(self, value: win32more.Microsoft.Windows.Foundation.DecimalValue) -> hstr: ...
    @winrt_commethod(33)
    def ToStringInvariant(self, value: win32more.Microsoft.Windows.Foundation.DecimalValue) -> hstr: ...
    @winrt_commethod(34)
    def ToStringWithLocale(self, value: win32more.Microsoft.Windows.Foundation.DecimalValue, localeName: hstr) -> hstr: ...
    @winrt_commethod(35)
    def Equals(self, left: win32more.Microsoft.Windows.Foundation.DecimalValue, right: win32more.Microsoft.Windows.Foundation.DecimalValue) -> Boolean: ...
    @winrt_commethod(36)
    def Compare(self, left: win32more.Microsoft.Windows.Foundation.DecimalValue, right: win32more.Microsoft.Windows.Foundation.DecimalValue) -> Int32: ...
    @winrt_commethod(37)
    def IsValid(self, value: win32more.Microsoft.Windows.Foundation.DecimalValue) -> Boolean: ...
    @winrt_commethod(38)
    def IsInteger(self, value: win32more.Microsoft.Windows.Foundation.DecimalValue) -> Boolean: ...
    @winrt_commethod(39)
    def Scale(self, value: win32more.Microsoft.Windows.Foundation.DecimalValue) -> Byte: ...
    @winrt_commethod(40)
    def Sign(self, value: win32more.Microsoft.Windows.Foundation.DecimalValue) -> Int32: ...
    @winrt_commethod(41)
    def MaxScale(self) -> Byte: ...
    @winrt_commethod(42)
    def MaxValue(self) -> win32more.Microsoft.Windows.Foundation.DecimalValue: ...
    @winrt_commethod(43)
    def MinValue(self) -> win32more.Microsoft.Windows.Foundation.DecimalValue: ...
    @winrt_commethod(44)
    def Negate(self, value: win32more.Microsoft.Windows.Foundation.DecimalValue) -> win32more.Microsoft.Windows.Foundation.DecimalValue: ...
    @winrt_commethod(45)
    def Abs(self, value: win32more.Microsoft.Windows.Foundation.DecimalValue) -> win32more.Microsoft.Windows.Foundation.DecimalValue: ...
    @winrt_commethod(46)
    def Truncate(self, value: win32more.Microsoft.Windows.Foundation.DecimalValue) -> win32more.Microsoft.Windows.Foundation.DecimalValue: ...
    @winrt_commethod(47)
    def Floor(self, value: win32more.Microsoft.Windows.Foundation.DecimalValue) -> win32more.Microsoft.Windows.Foundation.DecimalValue: ...
    @winrt_commethod(48)
    def Ceiling(self, value: win32more.Microsoft.Windows.Foundation.DecimalValue) -> win32more.Microsoft.Windows.Foundation.DecimalValue: ...
    @winrt_commethod(49)
    def Round(self, value: win32more.Microsoft.Windows.Foundation.DecimalValue, decimalPlaces: Int32) -> win32more.Microsoft.Windows.Foundation.DecimalValue: ...
    @winrt_commethod(50)
    def Clamp(self, value: win32more.Microsoft.Windows.Foundation.DecimalValue, min: win32more.Microsoft.Windows.Foundation.DecimalValue, max: win32more.Microsoft.Windows.Foundation.DecimalValue) -> win32more.Microsoft.Windows.Foundation.DecimalValue: ...
    @winrt_commethod(51)
    def Add(self, left: win32more.Microsoft.Windows.Foundation.DecimalValue, right: win32more.Microsoft.Windows.Foundation.DecimalValue) -> win32more.Microsoft.Windows.Foundation.DecimalValue: ...
    @winrt_commethod(52)
    def Subtract(self, left: win32more.Microsoft.Windows.Foundation.DecimalValue, right: win32more.Microsoft.Windows.Foundation.DecimalValue) -> win32more.Microsoft.Windows.Foundation.DecimalValue: ...
    @winrt_commethod(53)
    def Multiply(self, left: win32more.Microsoft.Windows.Foundation.DecimalValue, right: win32more.Microsoft.Windows.Foundation.DecimalValue) -> win32more.Microsoft.Windows.Foundation.DecimalValue: ...
    @winrt_commethod(54)
    def Divide(self, left: win32more.Microsoft.Windows.Foundation.DecimalValue, right: win32more.Microsoft.Windows.Foundation.DecimalValue) -> win32more.Microsoft.Windows.Foundation.DecimalValue: ...
    @winrt_commethod(55)
    def Modulo(self, left: win32more.Microsoft.Windows.Foundation.DecimalValue, right: win32more.Microsoft.Windows.Foundation.DecimalValue) -> win32more.Microsoft.Windows.Foundation.DecimalValue: ...


make_ready(__name__)



from __future__ import annotations
from win32more._prelude import *
import win32more.Microsoft.UI
import win32more.Microsoft.Windows.Storage.Pickers
import win32more.Windows.Foundation
import win32more.Windows.Foundation.Collections
class FileOpenPicker(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.Windows.Storage.Pickers.IFileOpenPicker
    _classid_ = 'Microsoft.Windows.Storage.Pickers.FileOpenPicker'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 1:
            super().__init__(move=win32more.Microsoft.Windows.Storage.Pickers.FileOpenPicker.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Microsoft.Windows.Storage.Pickers.IFileOpenPickerFactory, windowId: win32more.Microsoft.UI.WindowId) -> win32more.Microsoft.Windows.Storage.Pickers.FileOpenPicker: ...
    @winrt_mixinmethod
    def get_ViewMode(self: win32more.Microsoft.Windows.Storage.Pickers.IFileOpenPicker) -> win32more.Microsoft.Windows.Storage.Pickers.PickerViewMode: ...
    @winrt_mixinmethod
    def put_ViewMode(self: win32more.Microsoft.Windows.Storage.Pickers.IFileOpenPicker, value: win32more.Microsoft.Windows.Storage.Pickers.PickerViewMode) -> Void: ...
    @winrt_mixinmethod
    def get_SuggestedStartLocation(self: win32more.Microsoft.Windows.Storage.Pickers.IFileOpenPicker) -> win32more.Microsoft.Windows.Storage.Pickers.PickerLocationId: ...
    @winrt_mixinmethod
    def put_SuggestedStartLocation(self: win32more.Microsoft.Windows.Storage.Pickers.IFileOpenPicker, value: win32more.Microsoft.Windows.Storage.Pickers.PickerLocationId) -> Void: ...
    @winrt_mixinmethod
    def get_CommitButtonText(self: win32more.Microsoft.Windows.Storage.Pickers.IFileOpenPicker) -> hstr: ...
    @winrt_mixinmethod
    def put_CommitButtonText(self: win32more.Microsoft.Windows.Storage.Pickers.IFileOpenPicker, value: hstr) -> Void: ...
    @winrt_mixinmethod
    def get_FileTypeFilter(self: win32more.Microsoft.Windows.Storage.Pickers.IFileOpenPicker) -> win32more.Windows.Foundation.Collections.IVector[hstr]: ...
    @winrt_mixinmethod
    def PickSingleFileAsync(self: win32more.Microsoft.Windows.Storage.Pickers.IFileOpenPicker) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Microsoft.Windows.Storage.Pickers.PickFileResult]: ...
    @winrt_mixinmethod
    def PickMultipleFilesAsync(self: win32more.Microsoft.Windows.Storage.Pickers.IFileOpenPicker) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Foundation.Collections.IVectorView[win32more.Microsoft.Windows.Storage.Pickers.PickFileResult]]: ...
    CommitButtonText = property(get_CommitButtonText, put_CommitButtonText)
    FileTypeFilter = property(get_FileTypeFilter, None)
    SuggestedStartLocation = property(get_SuggestedStartLocation, put_SuggestedStartLocation)
    ViewMode = property(get_ViewMode, put_ViewMode)
class FileSavePicker(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.Windows.Storage.Pickers.IFileSavePicker
    _classid_ = 'Microsoft.Windows.Storage.Pickers.FileSavePicker'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 1:
            super().__init__(move=win32more.Microsoft.Windows.Storage.Pickers.FileSavePicker.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Microsoft.Windows.Storage.Pickers.IFileSavePickerFactory, windowId: win32more.Microsoft.UI.WindowId) -> win32more.Microsoft.Windows.Storage.Pickers.FileSavePicker: ...
    @winrt_mixinmethod
    def get_SuggestedStartLocation(self: win32more.Microsoft.Windows.Storage.Pickers.IFileSavePicker) -> win32more.Microsoft.Windows.Storage.Pickers.PickerLocationId: ...
    @winrt_mixinmethod
    def put_SuggestedStartLocation(self: win32more.Microsoft.Windows.Storage.Pickers.IFileSavePicker, value: win32more.Microsoft.Windows.Storage.Pickers.PickerLocationId) -> Void: ...
    @winrt_mixinmethod
    def get_CommitButtonText(self: win32more.Microsoft.Windows.Storage.Pickers.IFileSavePicker) -> hstr: ...
    @winrt_mixinmethod
    def put_CommitButtonText(self: win32more.Microsoft.Windows.Storage.Pickers.IFileSavePicker, value: hstr) -> Void: ...
    @winrt_mixinmethod
    def get_FileTypeChoices(self: win32more.Microsoft.Windows.Storage.Pickers.IFileSavePicker) -> win32more.Windows.Foundation.Collections.IMap[hstr, win32more.Windows.Foundation.Collections.IVector[hstr]]: ...
    @winrt_mixinmethod
    def get_DefaultFileExtension(self: win32more.Microsoft.Windows.Storage.Pickers.IFileSavePicker) -> hstr: ...
    @winrt_mixinmethod
    def put_DefaultFileExtension(self: win32more.Microsoft.Windows.Storage.Pickers.IFileSavePicker, value: hstr) -> Void: ...
    @winrt_mixinmethod
    def get_SuggestedFileName(self: win32more.Microsoft.Windows.Storage.Pickers.IFileSavePicker) -> hstr: ...
    @winrt_mixinmethod
    def put_SuggestedFileName(self: win32more.Microsoft.Windows.Storage.Pickers.IFileSavePicker, value: hstr) -> Void: ...
    @winrt_mixinmethod
    def get_SuggestedFolder(self: win32more.Microsoft.Windows.Storage.Pickers.IFileSavePicker) -> hstr: ...
    @winrt_mixinmethod
    def put_SuggestedFolder(self: win32more.Microsoft.Windows.Storage.Pickers.IFileSavePicker, value: hstr) -> Void: ...
    @winrt_mixinmethod
    def PickSaveFileAsync(self: win32more.Microsoft.Windows.Storage.Pickers.IFileSavePicker) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Microsoft.Windows.Storage.Pickers.PickFileResult]: ...
    CommitButtonText = property(get_CommitButtonText, put_CommitButtonText)
    DefaultFileExtension = property(get_DefaultFileExtension, put_DefaultFileExtension)
    FileTypeChoices = property(get_FileTypeChoices, None)
    SuggestedFileName = property(get_SuggestedFileName, put_SuggestedFileName)
    SuggestedFolder = property(get_SuggestedFolder, put_SuggestedFolder)
    SuggestedStartLocation = property(get_SuggestedStartLocation, put_SuggestedStartLocation)
class FolderPicker(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.Windows.Storage.Pickers.IFolderPicker
    _classid_ = 'Microsoft.Windows.Storage.Pickers.FolderPicker'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 1:
            super().__init__(move=win32more.Microsoft.Windows.Storage.Pickers.FolderPicker.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Microsoft.Windows.Storage.Pickers.IFolderPickerFactory, windowId: win32more.Microsoft.UI.WindowId) -> win32more.Microsoft.Windows.Storage.Pickers.FolderPicker: ...
    @winrt_mixinmethod
    def get_ViewMode(self: win32more.Microsoft.Windows.Storage.Pickers.IFolderPicker) -> win32more.Microsoft.Windows.Storage.Pickers.PickerViewMode: ...
    @winrt_mixinmethod
    def put_ViewMode(self: win32more.Microsoft.Windows.Storage.Pickers.IFolderPicker, value: win32more.Microsoft.Windows.Storage.Pickers.PickerViewMode) -> Void: ...
    @winrt_mixinmethod
    def get_SuggestedStartLocation(self: win32more.Microsoft.Windows.Storage.Pickers.IFolderPicker) -> win32more.Microsoft.Windows.Storage.Pickers.PickerLocationId: ...
    @winrt_mixinmethod
    def put_SuggestedStartLocation(self: win32more.Microsoft.Windows.Storage.Pickers.IFolderPicker, value: win32more.Microsoft.Windows.Storage.Pickers.PickerLocationId) -> Void: ...
    @winrt_mixinmethod
    def get_CommitButtonText(self: win32more.Microsoft.Windows.Storage.Pickers.IFolderPicker) -> hstr: ...
    @winrt_mixinmethod
    def put_CommitButtonText(self: win32more.Microsoft.Windows.Storage.Pickers.IFolderPicker, value: hstr) -> Void: ...
    @winrt_mixinmethod
    def PickSingleFolderAsync(self: win32more.Microsoft.Windows.Storage.Pickers.IFolderPicker) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Microsoft.Windows.Storage.Pickers.PickFolderResult]: ...
    CommitButtonText = property(get_CommitButtonText, put_CommitButtonText)
    SuggestedStartLocation = property(get_SuggestedStartLocation, put_SuggestedStartLocation)
    ViewMode = property(get_ViewMode, put_ViewMode)
class IFileOpenPicker(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.Windows.Storage.Pickers.IFileOpenPicker'
    _iid_ = Guid('{9d00f175-c783-51bd-8c93-fb63695d3abc}')
    @winrt_commethod(6)
    def get_ViewMode(self) -> win32more.Microsoft.Windows.Storage.Pickers.PickerViewMode: ...
    @winrt_commethod(7)
    def put_ViewMode(self, value: win32more.Microsoft.Windows.Storage.Pickers.PickerViewMode) -> Void: ...
    @winrt_commethod(8)
    def get_SuggestedStartLocation(self) -> win32more.Microsoft.Windows.Storage.Pickers.PickerLocationId: ...
    @winrt_commethod(9)
    def put_SuggestedStartLocation(self, value: win32more.Microsoft.Windows.Storage.Pickers.PickerLocationId) -> Void: ...
    @winrt_commethod(10)
    def get_CommitButtonText(self) -> hstr: ...
    @winrt_commethod(11)
    def put_CommitButtonText(self, value: hstr) -> Void: ...
    @winrt_commethod(12)
    def get_FileTypeFilter(self) -> win32more.Windows.Foundation.Collections.IVector[hstr]: ...
    @winrt_commethod(13)
    def PickSingleFileAsync(self) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Microsoft.Windows.Storage.Pickers.PickFileResult]: ...
    @winrt_commethod(14)
    def PickMultipleFilesAsync(self) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Foundation.Collections.IVectorView[win32more.Microsoft.Windows.Storage.Pickers.PickFileResult]]: ...
    CommitButtonText = property(get_CommitButtonText, put_CommitButtonText)
    FileTypeFilter = property(get_FileTypeFilter, None)
    SuggestedStartLocation = property(get_SuggestedStartLocation, put_SuggestedStartLocation)
    ViewMode = property(get_ViewMode, put_ViewMode)
class IFileOpenPickerFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.Windows.Storage.Pickers.IFileOpenPickerFactory'
    _iid_ = Guid('{315e86d7-d7a2-5d81-b379-7af78207b1af}')
    @winrt_commethod(6)
    def CreateInstance(self, windowId: win32more.Microsoft.UI.WindowId) -> win32more.Microsoft.Windows.Storage.Pickers.FileOpenPicker: ...
class IFileSavePicker(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.Windows.Storage.Pickers.IFileSavePicker'
    _iid_ = Guid('{79f1f4df-741b-59b2-aa06-fe9ac817b7dd}')
    @winrt_commethod(6)
    def get_SuggestedStartLocation(self) -> win32more.Microsoft.Windows.Storage.Pickers.PickerLocationId: ...
    @winrt_commethod(7)
    def put_SuggestedStartLocation(self, value: win32more.Microsoft.Windows.Storage.Pickers.PickerLocationId) -> Void: ...
    @winrt_commethod(8)
    def get_CommitButtonText(self) -> hstr: ...
    @winrt_commethod(9)
    def put_CommitButtonText(self, value: hstr) -> Void: ...
    @winrt_commethod(10)
    def get_FileTypeChoices(self) -> win32more.Windows.Foundation.Collections.IMap[hstr, win32more.Windows.Foundation.Collections.IVector[hstr]]: ...
    @winrt_commethod(11)
    def get_DefaultFileExtension(self) -> hstr: ...
    @winrt_commethod(12)
    def put_DefaultFileExtension(self, value: hstr) -> Void: ...
    @winrt_commethod(13)
    def get_SuggestedFileName(self) -> hstr: ...
    @winrt_commethod(14)
    def put_SuggestedFileName(self, value: hstr) -> Void: ...
    @winrt_commethod(15)
    def get_SuggestedFolder(self) -> hstr: ...
    @winrt_commethod(16)
    def put_SuggestedFolder(self, value: hstr) -> Void: ...
    @winrt_commethod(17)
    def PickSaveFileAsync(self) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Microsoft.Windows.Storage.Pickers.PickFileResult]: ...
    CommitButtonText = property(get_CommitButtonText, put_CommitButtonText)
    DefaultFileExtension = property(get_DefaultFileExtension, put_DefaultFileExtension)
    FileTypeChoices = property(get_FileTypeChoices, None)
    SuggestedFileName = property(get_SuggestedFileName, put_SuggestedFileName)
    SuggestedFolder = property(get_SuggestedFolder, put_SuggestedFolder)
    SuggestedStartLocation = property(get_SuggestedStartLocation, put_SuggestedStartLocation)
class IFileSavePickerFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.Windows.Storage.Pickers.IFileSavePickerFactory'
    _iid_ = Guid('{2e256696-30b6-5a05-a8f5-c752db6dd268}')
    @winrt_commethod(6)
    def CreateInstance(self, windowId: win32more.Microsoft.UI.WindowId) -> win32more.Microsoft.Windows.Storage.Pickers.FileSavePicker: ...
class IFolderPicker(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.Windows.Storage.Pickers.IFolderPicker'
    _iid_ = Guid('{3ef0d1ca-97c6-5873-8ea2-02c450174290}')
    @winrt_commethod(6)
    def get_ViewMode(self) -> win32more.Microsoft.Windows.Storage.Pickers.PickerViewMode: ...
    @winrt_commethod(7)
    def put_ViewMode(self, value: win32more.Microsoft.Windows.Storage.Pickers.PickerViewMode) -> Void: ...
    @winrt_commethod(8)
    def get_SuggestedStartLocation(self) -> win32more.Microsoft.Windows.Storage.Pickers.PickerLocationId: ...
    @winrt_commethod(9)
    def put_SuggestedStartLocation(self, value: win32more.Microsoft.Windows.Storage.Pickers.PickerLocationId) -> Void: ...
    @winrt_commethod(10)
    def get_CommitButtonText(self) -> hstr: ...
    @winrt_commethod(11)
    def put_CommitButtonText(self, value: hstr) -> Void: ...
    @winrt_commethod(12)
    def PickSingleFolderAsync(self) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Microsoft.Windows.Storage.Pickers.PickFolderResult]: ...
    CommitButtonText = property(get_CommitButtonText, put_CommitButtonText)
    SuggestedStartLocation = property(get_SuggestedStartLocation, put_SuggestedStartLocation)
    ViewMode = property(get_ViewMode, put_ViewMode)
class IFolderPickerFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.Windows.Storage.Pickers.IFolderPickerFactory'
    _iid_ = Guid('{e1550d89-b389-5886-8395-022b1588d6a8}')
    @winrt_commethod(6)
    def CreateInstance(self, windowId: win32more.Microsoft.UI.WindowId) -> win32more.Microsoft.Windows.Storage.Pickers.FolderPicker: ...
class IPickFileResult(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.Windows.Storage.Pickers.IPickFileResult'
    _iid_ = Guid('{e6f2e3d6-7bb0-5d81-9e7d-6fd35a1f25ab}')
    @winrt_commethod(6)
    def get_Path(self) -> hstr: ...
    Path = property(get_Path, None)
class IPickFolderResult(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.Windows.Storage.Pickers.IPickFolderResult'
    _iid_ = Guid('{6f7fd316-fe29-59d1-9343-c49cf5cde680}')
    @winrt_commethod(6)
    def get_Path(self) -> hstr: ...
    Path = property(get_Path, None)
class PickFileResult(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.Windows.Storage.Pickers.IPickFileResult
    _classid_ = 'Microsoft.Windows.Storage.Pickers.PickFileResult'
    @winrt_mixinmethod
    def get_Path(self: win32more.Microsoft.Windows.Storage.Pickers.IPickFileResult) -> hstr: ...
    Path = property(get_Path, None)
class PickFolderResult(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.Windows.Storage.Pickers.IPickFolderResult
    _classid_ = 'Microsoft.Windows.Storage.Pickers.PickFolderResult'
    @winrt_mixinmethod
    def get_Path(self: win32more.Microsoft.Windows.Storage.Pickers.IPickFolderResult) -> hstr: ...
    Path = property(get_Path, None)
class PickerLocationId(Enum, Int32):
    DocumentsLibrary = 0
    ComputerFolder = 1
    Desktop = 2
    Downloads = 3
    MusicLibrary = 5
    PicturesLibrary = 6
    VideosLibrary = 7
    Objects3D = 8
    Unspecified = 9
class PickerViewMode(Enum, Int32):
    List = 0
    Thumbnail = 1
StoragePickersContract: UInt32 = 65544


make_ready(__name__)



from __future__ import annotations
from win32more._prelude import *
import win32more.Microsoft.Windows.AI.MachineLearning
import win32more.Windows.ApplicationModel
import win32more.Windows.Foundation
import win32more.Windows.Foundation.Collections
class ExecutionProvider(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.Windows.AI.MachineLearning.IExecutionProvider
    _classid_ = 'Microsoft.Windows.AI.MachineLearning.ExecutionProvider'
    @winrt_mixinmethod
    def get_Name(self: win32more.Microsoft.Windows.AI.MachineLearning.IExecutionProvider) -> hstr: ...
    @winrt_mixinmethod
    def get_LibraryPath(self: win32more.Microsoft.Windows.AI.MachineLearning.IExecutionProvider) -> hstr: ...
    @winrt_mixinmethod
    def get_PackageId(self: win32more.Microsoft.Windows.AI.MachineLearning.IExecutionProvider) -> win32more.Windows.ApplicationModel.PackageId: ...
    @winrt_mixinmethod
    def get_ReadyState(self: win32more.Microsoft.Windows.AI.MachineLearning.IExecutionProvider) -> win32more.Microsoft.Windows.AI.MachineLearning.ExecutionProviderReadyState: ...
    @winrt_mixinmethod
    def get_Certification(self: win32more.Microsoft.Windows.AI.MachineLearning.IExecutionProvider) -> win32more.Microsoft.Windows.AI.MachineLearning.ExecutionProviderCertification: ...
    @winrt_mixinmethod
    def EnsureReadyAsync(self: win32more.Microsoft.Windows.AI.MachineLearning.IExecutionProvider) -> win32more.Windows.Foundation.IAsyncOperationWithProgress[win32more.Microsoft.Windows.AI.MachineLearning.ExecutionProviderReadyResult, Double]: ...
    @winrt_mixinmethod
    def TryRegister(self: win32more.Microsoft.Windows.AI.MachineLearning.IExecutionProvider) -> Boolean: ...
    Certification = property(get_Certification, None)
    LibraryPath = property(get_LibraryPath, None)
    Name = property(get_Name, None)
    PackageId = property(get_PackageId, None)
    ReadyState = property(get_ReadyState, None)
class ExecutionProviderCatalog(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.Windows.AI.MachineLearning.IExecutionProviderCatalog
    _classid_ = 'Microsoft.Windows.AI.MachineLearning.ExecutionProviderCatalog'
    @winrt_mixinmethod
    def FindAllProviders(self: win32more.Microsoft.Windows.AI.MachineLearning.IExecutionProviderCatalog) -> ReceiveArray[win32more.Microsoft.Windows.AI.MachineLearning.ExecutionProvider]: ...
    @winrt_mixinmethod
    def EnsureAndRegisterCertifiedAsync(self: win32more.Microsoft.Windows.AI.MachineLearning.IExecutionProviderCatalog) -> win32more.Windows.Foundation.IAsyncOperationWithProgress[win32more.Windows.Foundation.Collections.IVector[win32more.Microsoft.Windows.AI.MachineLearning.ExecutionProvider], Double]: ...
    @winrt_mixinmethod
    def RegisterCertifiedAsync(self: win32more.Microsoft.Windows.AI.MachineLearning.IExecutionProviderCatalog) -> win32more.Windows.Foundation.IAsyncOperationWithProgress[win32more.Windows.Foundation.Collections.IVector[win32more.Microsoft.Windows.AI.MachineLearning.ExecutionProvider], Double]: ...
    @winrt_classmethod
    def GetDefault(cls: win32more.Microsoft.Windows.AI.MachineLearning.IExecutionProviderCatalogStatics) -> win32more.Microsoft.Windows.AI.MachineLearning.ExecutionProviderCatalog: ...
class ExecutionProviderCertification(Enum, Int32):
    Unknown = 0
    Certified = 1
    Uncertified = 2
class ExecutionProviderReadyResult(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.Windows.AI.MachineLearning.IExecutionProviderReadyResult
    _classid_ = 'Microsoft.Windows.AI.MachineLearning.ExecutionProviderReadyResult'
    @winrt_mixinmethod
    def get_Status(self: win32more.Microsoft.Windows.AI.MachineLearning.IExecutionProviderReadyResult) -> win32more.Microsoft.Windows.AI.MachineLearning.ExecutionProviderReadyResultState: ...
    @winrt_mixinmethod
    def get_ExtendedError(self: win32more.Microsoft.Windows.AI.MachineLearning.IExecutionProviderReadyResult) -> win32more.Windows.Foundation.HResult: ...
    @winrt_mixinmethod
    def get_DiagnosticText(self: win32more.Microsoft.Windows.AI.MachineLearning.IExecutionProviderReadyResult) -> hstr: ...
    DiagnosticText = property(get_DiagnosticText, None)
    ExtendedError = property(get_ExtendedError, None)
    Status = property(get_Status, None)
class ExecutionProviderReadyResultState(Enum, Int32):
    InProgress = 0
    Success = 1
    Failure = 2
class ExecutionProviderReadyState(Enum, Int32):
    Ready = 0
    NotReady = 1
    NotPresent = 2
class IExecutionProvider(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.Windows.AI.MachineLearning.IExecutionProvider'
    _iid_ = Guid('{98356468-cf23-504f-b29c-9347781925ff}')
    @winrt_commethod(6)
    def get_Name(self) -> hstr: ...
    @winrt_commethod(7)
    def get_LibraryPath(self) -> hstr: ...
    @winrt_commethod(8)
    def get_PackageId(self) -> win32more.Windows.ApplicationModel.PackageId: ...
    @winrt_commethod(9)
    def get_ReadyState(self) -> win32more.Microsoft.Windows.AI.MachineLearning.ExecutionProviderReadyState: ...
    @winrt_commethod(10)
    def get_Certification(self) -> win32more.Microsoft.Windows.AI.MachineLearning.ExecutionProviderCertification: ...
    @winrt_commethod(11)
    def EnsureReadyAsync(self) -> win32more.Windows.Foundation.IAsyncOperationWithProgress[win32more.Microsoft.Windows.AI.MachineLearning.ExecutionProviderReadyResult, Double]: ...
    @winrt_commethod(12)
    def TryRegister(self) -> Boolean: ...
    Certification = property(get_Certification, None)
    LibraryPath = property(get_LibraryPath, None)
    Name = property(get_Name, None)
    PackageId = property(get_PackageId, None)
    ReadyState = property(get_ReadyState, None)
class IExecutionProviderCatalog(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.Windows.AI.MachineLearning.IExecutionProviderCatalog'
    _iid_ = Guid('{aa9bfe14-2222-5921-8002-4d2a205ea03c}')
    @winrt_commethod(6)
    def FindAllProviders(self) -> ReceiveArray[win32more.Microsoft.Windows.AI.MachineLearning.ExecutionProvider]: ...
    @winrt_commethod(7)
    def EnsureAndRegisterCertifiedAsync(self) -> win32more.Windows.Foundation.IAsyncOperationWithProgress[win32more.Windows.Foundation.Collections.IVector[win32more.Microsoft.Windows.AI.MachineLearning.ExecutionProvider], Double]: ...
    @winrt_commethod(8)
    def RegisterCertifiedAsync(self) -> win32more.Windows.Foundation.IAsyncOperationWithProgress[win32more.Windows.Foundation.Collections.IVector[win32more.Microsoft.Windows.AI.MachineLearning.ExecutionProvider], Double]: ...
class IExecutionProviderCatalogStatics(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.Windows.AI.MachineLearning.IExecutionProviderCatalogStatics'
    _iid_ = Guid('{550def98-2611-5433-afb8-43673b610848}')
    @winrt_commethod(6)
    def GetDefault(self) -> win32more.Microsoft.Windows.AI.MachineLearning.ExecutionProviderCatalog: ...
class IExecutionProviderReadyResult(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.Windows.AI.MachineLearning.IExecutionProviderReadyResult'
    _iid_ = Guid('{91c1724d-93c7-5284-adbe-ba2bd7be7c79}')
    @winrt_commethod(6)
    def get_Status(self) -> win32more.Microsoft.Windows.AI.MachineLearning.ExecutionProviderReadyResultState: ...
    @winrt_commethod(7)
    def get_ExtendedError(self) -> win32more.Windows.Foundation.HResult: ...
    @winrt_commethod(8)
    def get_DiagnosticText(self) -> hstr: ...
    DiagnosticText = property(get_DiagnosticText, None)
    ExtendedError = property(get_ExtendedError, None)
    Status = property(get_Status, None)
MachineLearningContract: UInt32 = 131072


make_ready(__name__)



from __future__ import annotations
from win32more._prelude import *
import win32more.Microsoft.Windows.AI.Foundation
AIFoundationContract: UInt32 = 65536
class EmbeddingVector(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.Windows.AI.Foundation.IEmbeddingVector
    _classid_ = 'Microsoft.Windows.AI.Foundation.EmbeddingVector'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 2:
            super().__init__(move=win32more.Microsoft.Windows.AI.Foundation.EmbeddingVector.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Microsoft.Windows.AI.Foundation.IEmbeddingVectorFactory, data: PassArray[Single], vectorSpaceID: Guid) -> win32more.Microsoft.Windows.AI.Foundation.EmbeddingVector: ...
    @winrt_mixinmethod
    def GetValues(self: win32more.Microsoft.Windows.AI.Foundation.IEmbeddingVector, values: FillArray[Single]) -> Void: ...
    @winrt_mixinmethod
    def get_Size(self: win32more.Microsoft.Windows.AI.Foundation.IEmbeddingVector) -> UInt32: ...
    @winrt_mixinmethod
    def get_VectorSpaceId(self: win32more.Microsoft.Windows.AI.Foundation.IEmbeddingVector) -> Guid: ...
    Size = property(get_Size, None)
    VectorSpaceId = property(get_VectorSpaceId, None)
class IEmbeddingVector(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.Windows.AI.Foundation.IEmbeddingVector'
    _iid_ = Guid('{07bdaa90-b3d2-5701-97d1-c390ec62799c}')
    @winrt_commethod(6)
    def GetValues(self, values: FillArray[Single]) -> Void: ...
    @winrt_commethod(7)
    def get_Size(self) -> UInt32: ...
    @winrt_commethod(8)
    def get_VectorSpaceId(self) -> Guid: ...
    Size = property(get_Size, None)
    VectorSpaceId = property(get_VectorSpaceId, None)
class IEmbeddingVectorFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.Windows.AI.Foundation.IEmbeddingVectorFactory'
    _iid_ = Guid('{16b72758-2b69-5e97-b865-6a6a71683dd0}')
    @winrt_commethod(6)
    def CreateInstance(self, data: PassArray[Single], vectorSpaceID: Guid) -> win32more.Microsoft.Windows.AI.Foundation.EmbeddingVector: ...


make_ready(__name__)
